/***************************************************************************
                               cmudview.h
                             -------------------
    begin                : Sat Jun  16 22:10:48 CET 2001
    copyright            : (C) 2001 by Kmud Developer Team
    email                : kmud-devel@kmud.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CMUDVIEW_H
#define CMUDVIEW_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif 

// include files for Qt
#include <qwidget.h>
#include <qfont.h>
#include <qcolor.h>
#include <qstring.h>

// include files for KDE



class KTextBrowser;


class CMudView : public QWidget
{
	Q_OBJECT
public:
	/** Constructor for the main view */
	CMudView(QWidget *parent = 0, const char *name=0);
	/** Destructor for the main view */
	~CMudView();

	/** Set the defaults for Font, text color and background color.  */
	void init(const QFont font, const QColor textColor, const QColor bgColor);

	/** Sets the font for all following addText operations until the next setFont() or clear() call.
	Status of the style setting (bold, underline, italic) of the QFont object will be ignored
	if useStyle is false. */
	void setFont(QFont font, bool useStyle = false);
	/** Returns the currently used font, including the style settings.  */
	QFont font();
	/** Sets the underline style on if underline is true */
	void setUnderline(bool underline);
	/** Returns true if underline is active */
	bool underline();
	/** Sets the italic style on if italic is true */
	void setItalic(bool italic);
	/** Returns true if italic is active */
	bool italic();
	/** Sets the bold style on if bold is true */
	void setBold(bool bold);
	/** Returns true if bold is active */
	bool bold();
	/** Sets the text color. */
	void setTextColor(QColor color);
	/** Returns the currently used text color. */
	QColor textColor();
	/** Sets the text background color. */
	void setBgColor(QColor color);
	/** Returns the currently used text background color. */
	QColor bgColor();

public slots:
	/** Clears the view and resets font and color settings to the default values.
	If no default values were set, the font defaults to the QFont default, text color to red
	and background color to black. */
	void clear();

	/** Adds text to the view using the current settings for font, fontstyles (bold, underline, italic),
	text color and text background color*/
	void addText(const QString& text);

protected slots:
	void resizeEvent(QResizeEvent*);

private:

	// the text browser view
	KTextBrowser* _view;

	// current syle settings
	QFont _font;
	QColor _textColor;
	QColor _bgColor;

	// default style settings
	QFont _defaultFont;
	QColor _defaultTextColor;
	QColor _defaultBgColor;
		
};

#endif // KMUDVIEW_H

