/***************************************************************************
                               cmappluginbase.h
                             -------------------
    begin                : Mon Aug 6 2001
    copyright            : (C) 2001 by Kmud Developer Team
    email                : kmud-devel@kmud.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CMAPPLUGINBASE_H
#define CMAPPLUGINBASE_H

#include <qlist.h>
#include <kparts/plugin.h>

#include "cmapelement.h"

class CMapViewManagerBase;
class CMapToolBase;
class CMapPropertiesPaneBase;
class CMapManager;
class CMapRoom;
class KmudSetupPane;

/**This is the base class for mapper plugins
  *@author Kmud Developer Team
  */
class CMapPluginBase : public KParts::Plugin
{
   Q_OBJECT
public: 
	CMapPluginBase(CMapManager *manager,QObject *parent=0, const char *name=0);
	virtual ~CMapPluginBase();

	/** Used to get a list of the view managers */
	virtual QList<CMapViewManagerBase> getViewList(void);
	/** Used to get a list of the tools */
	virtual QList<CMapToolBase> getToolList(void);
	/** Used to get a list of the property pages for a map element */
	virtual QList<CMapPropertiesPaneBase> getPropertyPanes(elementTyp type,CMapElement *element,QWidget *parent);
	/** This method is used to get a list of global config panes. It should return a empty list
	  * If none are provided by this part */
	virtual QList<KmudSetupPane> createGlobalConfigPanes(QWidget *);
	/** This method is used to get a list of profile config panes. It should return a empty list
	  * If none are provided by this part */
	virtual QList<KmudSetupPane> createProfileConfigPanes(QWidget *);


	/** Used to tell the tool were to find the map manager */
	void setManager(CMapManager *manager);
	/** Used to get the map manager */
	CMapManager *getManager(void);

	/** This is called before a element menu is openend */
	virtual void beforeOpenElementMenu(CMapElement *element);
	/** This is called before a element is deleted */
	virtual void beforeElementDeleted(CMapElement *element);
	/** This is called when a element is changed */
	virtual void elementChanged(CMapElement *element);
	virtual void saveConfigOptions(void);
	virtual void loadConfigOptions(void);
	virtual void mapErased(void);
	/** Request that a room be added to the speedwalk list
      * @param room The room to be added */
	virtual void addSpeedwalkRoom(CMapRoom *) { };
	/** This is called when the character or mud profiles change */
	virtual void profileChanged(void) { };
	/** This method is called when profile data changes */
	virtual void profileDataChanged(const QString& , uint ) { }
	
protected:
	QList<CMapToolBase>            toolList;
	QList<CMapViewManagerBase>     viewList;
	QList<CMapPropertiesPaneBase>  paneList;

	CMapManager *mapManager;
};

#endif
